@@ -262,9 +262,8 @@ def _run_command(
     python_module = COMMAND_TO_PYTHON_MODULE.get(command, command)
     output = subprocess.run(
         [sys.executable, "-m", python_module, *args, *cmd_args],
-        stderr=subprocess.PIPE,
-        stdout=subprocess.PIPE,
-        universal_newlines=True,  # from Python3.7 this can be replaced with `text`
+        capture_output=True,
+        text=True,
         env=my_env,
     )
 
@@ -643,7 +642,10 @@ def _main(cli_args: CLIArgs, configs: Configs) -> int:
                 sys.stdout.write(
                     "To apply these changes, remove the `--nbqa-diff` flag\n"
                 )
-            return output_code
+            else:
+                sys.stdout.write("Notebook(s) would be left unchanged\n")
+            # For diff, we return 0 if no mutation would've occurred, and 1 otherwise.
+            return int(mutated)
 
     finally:
         _clean_up_tmp_files(nb_to_tmp_mapping)
